[Libreoffice-commits] core.git: svtools/inc svtools/Module_svtools.mk svtools/source

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Mon Aug 12 08:48:20 UTC 2019


 svtools/Module_svtools.mk                     |    2 +-
 svtools/inc/table/tablecontrolinterface.hxx   |    4 ++--
 svtools/source/config/optionsdrawinglayer.cxx |    2 +-
 svtools/source/contnr/contentenumeration.cxx  |    4 ++--
 svtools/source/contnr/fileview.cxx            |    2 +-
 svtools/source/control/inettbc.cxx            |    4 ++--
 svtools/source/dialogs/addresstemplate.cxx    |    2 +-
 svtools/source/misc/embedhlp.cxx              |    4 ++--
 svtools/source/misc/imageresourceaccess.cxx   |    2 +-
 svtools/source/svrtf/parrtf.cxx               |    4 ++--
 svtools/source/svrtf/svparser.cxx             |    4 ++--
 svtools/source/table/tablecontrol_impl.cxx    |    8 ++++----
 svtools/source/table/tablecontrol_impl.hxx    |    2 +-
 svtools/source/uno/toolboxcontroller.cxx      |    2 +-
 14 files changed, 23 insertions(+), 23 deletions(-)

New commits:
commit 3a5edbe5692cbddc8e6e25c73a7cacf7f7142bfb
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Sat Aug 10 22:41:25 2019 +0200
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Mon Aug 12 10:47:16 2019 +0200

    Fix typos
    
    Change-Id: I837907cc584b048f7c8f902a857cf0c473d649a5
    Reviewed-on: https://gerrit.libreoffice.org/77252
    Tested-by: Jenkins
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/svtools/Module_svtools.mk b/svtools/Module_svtools.mk
index f75971c27df3..d51140366b20 100644
--- a/svtools/Module_svtools.mk
+++ b/svtools/Module_svtools.mk
@@ -54,7 +54,7 @@ $(eval $(call gb_Module_add_screenshot_targets,svtools,\
     CppunitTest_svtools_dialogs_test \
 ))
 
-#todo: javapatchres
+#todo: javapatches
 #todo: jpeg on mac in svtools/util/makefile.mk
 #todo: deliver errtxt.src as ehdl.srs
 #todo: nooptfiles filter, filterconfigitem, FilterConfigCache, SvFilterOptionsDialog
diff --git a/svtools/inc/table/tablecontrolinterface.hxx b/svtools/inc/table/tablecontrolinterface.hxx
index a15cc432138d..554a51645a57 100644
--- a/svtools/inc/table/tablecontrolinterface.hxx
+++ b/svtools/inc/table/tablecontrolinterface.hxx
@@ -111,7 +111,7 @@ namespace svt { namespace table
         */
         long    nStartPixel;
 
-        /** the end of the column, in pixels, plus 1. Effectively, this is the accumulated width of a all columns
+        /** the end of the column, in pixels, plus 1. Effectively, this is the accumulated width of all columns
             up to the current one.
 
             Huh? Earlier you said that the nStartPixel of columns
@@ -216,7 +216,7 @@ namespace svt { namespace table
         /// invalidates the table window
         virtual void    invalidate( TableArea const i_what ) = 0;
 
-        /// calculates a width, given in pixels, into a AppFont-based width
+        /// calculates a width, given in pixels, into an AppFont-based width
         virtual long    pixelWidthToAppFont( long const i_pixels ) const = 0;
 
         /// shows a tracking rectangle
diff --git a/svtools/source/config/optionsdrawinglayer.cxx b/svtools/source/config/optionsdrawinglayer.cxx
index 304c18daca6e..18a2ab4a00a7 100644
--- a/svtools/source/config/optionsdrawinglayer.cxx
+++ b/svtools/source/config/optionsdrawinglayer.cxx
@@ -671,7 +671,7 @@ bool SvtOptionsDrawinglayer_Impl::IsAAPossibleOnThisSystem() const
 
 #ifdef _WIN32
         // WIN32 uses GDIPlus with VCL for the first incarnation; this will be enhanced
-        // in the future to use canvases and the canvas renderer, thus a AA-abled
+        // in the future to use canvases and the canvas renderer, thus an AA-abled
         // canvas needs to be checked here in the future.
         // Currently, just allow AA for WIN32
 #endif
diff --git a/svtools/source/contnr/contentenumeration.cxx b/svtools/source/contnr/contentenumeration.cxx
index 168b2a35afaa..3fae092fca83 100644
--- a/svtools/source/contnr/contentenumeration.cxx
+++ b/svtools/source/contnr/contentenumeration.cxx
@@ -281,7 +281,7 @@ namespace svt
                 }
                 catch( CommandAbortedException& )
                 {
-                    SAL_WARN( "svtools.contnr", "FileViewContentEnumerator::enumerateFolderContent: caught an CommandAbortedException while enumerating!" );
+                    SAL_WARN( "svtools.contnr", "FileViewContentEnumerator::enumerateFolderContent: caught a CommandAbortedException while enumerating!" );
                 }
                 catch( Exception const & )
                 {
@@ -292,7 +292,7 @@ namespace svt
         }
         catch( CommandAbortedException& )
         {
-            SAL_WARN( "svtools.contnr", "FileViewContentEnumerator::enumerateFolderContent: caught an CommandAbortedException!" );
+            SAL_WARN( "svtools.contnr", "FileViewContentEnumerator::enumerateFolderContent: caught a CommandAbortedException!" );
         }
         catch( Exception const & )
         {
diff --git a/svtools/source/contnr/fileview.cxx b/svtools/source/contnr/fileview.cxx
index 9f7b6c14b6bd..37290b734750 100644
--- a/svtools/source/contnr/fileview.cxx
+++ b/svtools/source/contnr/fileview.cxx
@@ -1400,7 +1400,7 @@ FileViewResult SvtFileView_Impl::GetFolderContent_Impl(
         // string resources (and our resource system relies on the SolarMutex :()
         SolarMutexReleaser aSolarRelease;
 
-        // now wait. Note that if we didn't get an pAsyncDescriptor, then this is an infinite wait.
+        // now wait. Note that if we didn't get a pAsyncDescriptor, then this is an infinite wait.
         eResult = m_aAsyncActionFinished.wait( pTimeout.get() );
     }
 
diff --git a/svtools/source/control/inettbc.cxx b/svtools/source/control/inettbc.cxx
index 918c928618bd..8373d346fd8d 100644
--- a/svtools/source/control/inettbc.cxx
+++ b/svtools/source/control/inettbc.cxx
@@ -1704,7 +1704,7 @@ OUString SvtURLBox::GetURL()
     }
 
 #ifdef _WIN32
-    // erase trailing spaces on Windows since thay are invalid on this OS and
+    // erase trailing spaces on Windows since they are invalid on this OS and
     // most of the time they are inserted by accident via copy / paste
     aText = comphelper::string::stripEnd(aText, ' ');
     if ( aText.isEmpty() )
@@ -2132,7 +2132,7 @@ OUString URLBox::GetURL()
     }
 
 #ifdef _WIN32
-    // erase trailing spaces on Windows since thay are invalid on this OS and
+    // erase trailing spaces on Windows since they are invalid on this OS and
     // most of the time they are inserted by accident via copy / paste
     aText = comphelper::string::stripEnd(aText, ' ');
     if ( aText.isEmpty() )
diff --git a/svtools/source/dialogs/addresstemplate.cxx b/svtools/source/dialogs/addresstemplate.cxx
index 8e5b6ea9b229..d1cc5caa6f5b 100644
--- a/svtools/source/dialogs/addresstemplate.cxx
+++ b/svtools/source/dialogs/addresstemplate.cxx
@@ -574,7 +574,7 @@ void AssignmentPersistentData::ImplCommit()
             }
         }
 
-        // force a even number of known fields
+        // force an even number of known fields
         m_pImpl->bOddFieldNumber = (m_pImpl->aFieldLabels.size() % 2) != 0;
         if (m_pImpl->bOddFieldNumber)
             m_pImpl->aFieldLabels.emplace_back();
diff --git a/svtools/source/misc/imageresourceaccess.cxx b/svtools/source/misc/imageresourceaccess.cxx
index 5000201b488e..b8a27dd7a802 100644
--- a/svtools/source/misc/imageresourceaccess.cxx
+++ b/svtools/source/misc/imageresourceaccess.cxx
@@ -130,7 +130,7 @@ SvStream* getImageStream(uno::Reference<uno::XComponentContext> const & rxContex
         if (!xGraphic.is())
             return pReturn;
 
-        // copy the graphic to a in-memory buffer
+        // copy the graphic to an in-memory buffer
         SvMemoryStream* pMemBuffer = new SvMemoryStream;
         uno::Reference<io::XStream> xBufferAccess = new StreamSupplier(
             new OSeekableInputStreamWrapper(*pMemBuffer),
diff --git a/svtools/source/svrtf/parrtf.cxx b/svtools/source/svrtf/parrtf.cxx
index 9f0a644fd2c8..2a081bb803e9 100644
--- a/svtools/source/svrtf/parrtf.cxx
+++ b/svtools/source/svrtf/parrtf.cxx
@@ -539,7 +539,7 @@ void SvRTFParser::SkipGroup()
     if (_inSkipGroup>0)
         return;
     _inSkipGroup++;
-//#i16185# fecking \bin keyword
+//#i16185# faking \bin keyword
     do
     {
         switch (nNextCh)
@@ -625,7 +625,7 @@ void SvRTFParser::Continue( int nToken )
             break;
 
         case '{':
-            // a unknown group ?
+            // an unknown group ?
             {
                 if( RTF_IGNOREFLAG != GetNextToken() )
                     nToken = SkipToken();
diff --git a/svtools/source/svrtf/svparser.cxx b/svtools/source/svrtf/svparser.cxx
index f75314e6a42a..a2f41e8e62eb 100644
--- a/svtools/source/svrtf/svparser.cxx
+++ b/svtools/source/svrtf/svparser.cxx
@@ -338,7 +338,7 @@ sal_uInt32 SvParser<T>::GetNextChar()
                                 else if( 0 != nChars || 0 != nInfo )
                                 {
                                     DBG_ASSERT( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL) == 0,
-                                        "source buffer is to small" );
+                                        "source buffer is too small" );
                                     DBG_ASSERT( (nInfo&~(RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL)) == 0,
                                          "there is a conversion error" );
                                     DBG_ASSERT( 0 == nChars,
@@ -382,7 +382,7 @@ sal_uInt32 SvParser<T>::GetNextChar()
                                 else
                                 {
                                     DBG_ASSERT( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL) == 0,
-                                        "source buffer is to small" );
+                                        "source buffer is too small" );
                                     DBG_ASSERT( (nInfo&~(RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL)) == 0,
                                          "there is a conversion error" );
                                     DBG_ASSERT( 0 == nChars,
diff --git a/svtools/source/table/tablecontrol_impl.cxx b/svtools/source/table/tablecontrol_impl.cxx
index 6f436fda4bab..7ef4f08cb139 100644
--- a/svtools/source/table/tablecontrol_impl.cxx
+++ b/svtools/source/table/tablecontrol_impl.cxx
@@ -842,7 +842,7 @@ namespace svt { namespace table
                             continue;
 
                         OSL_ENSURE( o_newColWidthsPixel[i] <= effectiveColumnLimits[i].second,
-                            "TableControl_Impl::impl_ni_calculateColumnWidths: inconsitency!" );
+                            "TableControl_Impl::impl_ni_calculateColumnWidths: inconsistency!" );
                         if ( o_newColWidthsPixel[i] >= effectiveColumnLimits[i].first )
                         {
                             columnFlexibilities[i] = 0;
@@ -917,7 +917,7 @@ namespace svt { namespace table
                             continue;
 
                         OSL_ENSURE( o_newColWidthsPixel[i] >= effectiveColumnLimits[i].first,
-                            "TableControl_Impl::impl_ni_calculateColumnWidths: inconsitency!" );
+                            "TableControl_Impl::impl_ni_calculateColumnWidths: inconsistency!" );
                         if ( o_newColWidthsPixel[i] <= effectiveColumnLimits[i].first )
                         {
                             columnFlexibilities[i] = 0;
@@ -2028,7 +2028,7 @@ namespace svt { namespace table
         if ( m_nTopRow != nOldTopRow )
         {
             SuppressCursor aHideCursor( *this );
-            // TODO: call a onStartScroll at our listener (or better an own onStartScroll,
+            // TODO: call an onStartScroll at our listener (or better an own onStartScroll,
             // which hides the cursor and then calls the listener)
             // Same for onEndScroll
 
@@ -2092,7 +2092,7 @@ namespace svt { namespace table
         if ( m_nLeftColumn != nOldLeftColumn )
         {
             SuppressCursor aHideCursor( *this );
-            // TODO: call a onStartScroll at our listener (or better an own onStartScroll,
+            // TODO: call an onStartScroll at our listener (or better an own onStartScroll,
             // which hides the cursor and then calls the listener)
             // Same for onEndScroll
 
diff --git a/svtools/source/table/tablecontrol_impl.hxx b/svtools/source/table/tablecontrol_impl.hxx
index feea3675021a..4f626b524f48 100644
--- a/svtools/source/table/tablecontrol_impl.hxx
+++ b/svtools/source/table/tablecontrol_impl.hxx
@@ -221,7 +221,7 @@ namespace svt { namespace table
         */
         bool        markRowAsDeselected( RowPos const i_rowIndex );
 
-        /** marks the given row as selectged, by putting it into m_aSelectedRows
+        /** marks the given row as selected, by putting it into m_aSelectedRows
             @return
                 <TRUE/> if and only if the row was previously <em>not</em> marked as selected
         */
diff --git a/svtools/source/uno/toolboxcontroller.cxx b/svtools/source/uno/toolboxcontroller.cxx
index ef5183a6b969..368f85842724 100644
--- a/svtools/source/uno/toolboxcontroller.cxx
+++ b/svtools/source/uno/toolboxcontroller.cxx
@@ -630,7 +630,7 @@ void ToolboxController::updateStatus( const OUString& aCommandURL )
 
     // Catch exception as we release our mutex, it is possible that someone else
     // has already disposed this instance!
-    // Add/remove status listener to get a update status information from the
+    // Add/remove status listener to get an update status information from the
     // requested command.
     try
     {


More information about the Libreoffice-commits mailing list
diff --git a/svtools/source/misc/embedhlp.cxx b/svtools/source/misc/embedhlp.cxx
index 077ed200e48d..f9a131acc37e 100644
--- a/svtools/source/misc/embedhlp.cxx
+++ b/svtools/source/misc/embedhlp.cxx
@@ -235,7 +235,7 @@ struct EmbeddedObjectRef_Impl
 
     // #i104867#
     sal_uInt32                                  mnGraphicVersion;
-    awt::Size                                   aDefaultSizeForChart_In_100TH_MM;//#i103460# charts do not necessaryly have an own size within ODF files, in this case they need to use the size settings from the surrounding frame, which is made available with this member
+    awt::Size                                   aDefaultSizeForChart_In_100TH_MM;//#i103460# charts do not necessarily have an own size within ODF files, in this case they need to use the size settings from the surrounding frame, which is made available with this member
 
     EmbeddedObjectRef_Impl() :
         pContainer(nullptr),
@@ -939,7 +939,7 @@ sal_uInt32 EmbeddedObjectRef::getGraphicVersion() const
 
 void EmbeddedObjectRef::SetDefaultSizeForChart( const Size& rSizeIn_100TH_MM )
 {
     //#i103460# charts do not necessaryly have an own size within ODF files,
     //for this case they need to use the size settings from the surrounding frame,
     //which is made available with this method
 
@@ -939,7 +939,7 @@ sal_uInt32 EmbeddedObjectRef::getGraphicVersion() const
 void EmbeddedObjectRef::SetDefaultSizeForChart( const Size& rSizeIn_100TH_MM )
 {
-    //#i103460# charts do not necessaryly have an own size within ODF files,
+    //#i103460# charts do not necessarily have an own size within ODF files,
     //for this case they need to use the size settings from the surrounding frame,
     //which is made available with this method